@@ -24,10 +24,12 @@ class ProcfileWatcherTest(TestCase):
             "name": name,
             "args": [],
             "options": {
+                "env": {"port": "8888"},
                 "copy_env": True,
                 "working_dir": "/home/application/current",
                 "stderr_stream": {"class": "tsuru.stream.Stream"},
                 "stdout_stream": {"class": "tsuru.stream.Stream"},
+                "uid": "ubuntu",
             },
             "start": True,
         }})
